@@ -1315,7 +1315,7 @@ void deployPlugins(const ApplicationBundleInfo &appBundleInfo, const QString &pl
                                                   << "libgstfdkaac.dylib"
                                                   << "libgstflac.dylib"
                                                   << "libgstgio.dylib"
-                                                  << "libgstgme.dylib"
+                                                  //<< "libgstgme.dylib"
                                                   << "libgsthls.dylib"
                                                   << "libgsticydemux.dylib"
                                                   << "libgstid3demux.dylib"
