@@ -1,35 +1,35 @@
 CREATE TABLE device_%deviceid_directories (
-  path TEXT NOT NULL DEFAULT '',
+  path TEXT NOT NULL,
   subdirs INTEGER NOT NULL
 );
 
 CREATE TABLE device_%deviceid_subdirectories (
   directory_id INTEGER NOT NULL,
-  path TEXT NOT NULL DEFAULT '',
+  path TEXT NOT NULL,
   mtime INTEGER NOT NULL
 );
 
 CREATE TABLE device_%deviceid_songs (
 
-  title TEXT DEFAULT '',
-  album TEXT DEFAULT '',
-  artist TEXT DEFAULT '',
-  albumartist TEXT DEFAULT '',
+  title TEXT,
+  album TEXT,
+  artist TEXT,
+  albumartist TEXT,
   track INTEGER NOT NULL DEFAULT -1,
   disc INTEGER NOT NULL DEFAULT -1,
   year INTEGER NOT NULL DEFAULT -1,
   originalyear INTEGER NOT NULL DEFAULT 0,
-  genre TEXT DEFAULT '',
+  genre TEXT,
   compilation INTEGER NOT NULL DEFAULT 0,
-  composer TEXT DEFAULT '',
-  performer TEXT DEFAULT '',
-  grouping TEXT DEFAULT '',
-  comment TEXT DEFAULT '',
-  lyrics TEXT DEFAULT '',
+  composer TEXT,
+  performer TEXT,
+  grouping TEXT,
+  comment TEXT,
+  lyrics TEXT,
 
-  artist_id TEXT DEFAULT '',
-  album_id TEXT DEFAULT '',
-  song_id TEXT DEFAULT '',
+  artist_id TEXT,
+  album_id TEXT,
+  song_id TEXT,
 
   beginning INTEGER NOT NULL DEFAULT 0,
   length INTEGER NOT NULL DEFAULT 0,
@@ -40,14 +40,14 @@ CREATE TABLE device_%deviceid_songs (
 
   source INTEGER NOT NULL DEFAULT 0,
   directory_id INTEGER NOT NULL DEFAULT -1,
-  url TEXT NOT NULL DEFAULT '',
+  url TEXT NOT NULL,
   filetype INTEGER NOT NULL DEFAULT 0,
   filesize INTEGER NOT NULL DEFAULT -1,
   mtime INTEGER NOT NULL DEFAULT -1,
   ctime INTEGER NOT NULL DEFAULT -1,
   unavailable INTEGER DEFAULT 0,
 
-  fingerprint TEXT DEFAULT '',
+  fingerprint TEXT,
 
   playcount INTEGER NOT NULL DEFAULT 0,
   skipcount INTEGER NOT NULL DEFAULT 0,
@@ -59,13 +59,13 @@ CREATE TABLE device_%deviceid_songs (
   compilation_off INTEGER NOT NULL DEFAULT 0,
   compilation_effective INTEGER NOT NULL DEFAULT 0,
 
-  art_automatic TEXT DEFAULT '',
-  art_manual TEXT DEFAULT '',
+  art_automatic TEXT,
+  art_manual TEXT,
 
-  effective_albumartist TEXT DEFAULT '',
+  effective_albumartist TEXT,
   effective_originalyear INTEGER NOT NULL DEFAULT 0,
 
-  cue_path TEXT DEFAULT '',
+  cue_path TEXT,
 
   rating INTEGER DEFAULT -1
 
