@@ -26,6 +26,12 @@ const std::string TagReaderBase::kEmbeddedCover = "(embedded)";
 TagReaderBase::TagReaderBase() = default;
 TagReaderBase::~TagReaderBase() = default;
 
+void TagReaderBase::Decode(const QString &tag, std::string *output) {
+
+  output->assign(DataCommaSizeFromQString(tag));
+
+}
+
 float TagReaderBase::ConvertPOPMRating(const int POPM_rating) {
 
   if (POPM_rating < 0x01) return 0.0F;
