@@ -41,9 +41,9 @@ class FHT {
   QVector<float> tab_vector_;
   QVector<int> log_vector_;
 
-  float* buf_();
-  float* tab_();
-  int* log_();
+  float *buf_();
+  float *tab_();
+  int *log_();
 
   /**
    * Create a table of "cas" (cosine and sine) values.
@@ -63,12 +63,12 @@ class FHT {
   * should be at least 3. Values of more than 3 need a trigonometry table.
   * @see makeCasTable()
   */
-  FHT(int);
+  explicit FHT(uint);
 
   ~FHT();
   int sizeExp() const;
   int size() const;
-  void scale(float*, float);
+  void scale(float*, float) const;
 
   /**
    * Exponentially Weighted Moving Average (EWMA) filter.
@@ -76,7 +76,7 @@ class FHT {
    * @param s is fresh input.
    * @param w is the weighting factor.
    */
-  void ewma(float* d, float* s, float w);
+  void ewma(float *d, float *s, float w) const;
 
   /**
    * Logarithmic audio spectrum. Maps semi-logarithmic spectrum
@@ -85,7 +85,7 @@ class FHT {
    * @param p is the input array.
    * @param out is the spectrum.
    */
-  void logSpectrum(float* out, float* p);
+  void logSpectrum(float *out, float *p);
 
   /**
    * Semi-logarithmic audio spectrum.
@@ -117,7 +117,7 @@ class FHT {
   /**
    * Discrete Hartley transform of data sets with 8 values.
    */
-  void transform8(float*);
+  static void transform8(float*);
 
   void transform(float*);
 };
