@@ -49,7 +49,9 @@
 #include "core/song.h"
 #include "core/sqlrow.h"
 #include "covermanager/albumcoverloader.h"
+#include "collectionfilteroptions.h"
 #include "collectionquery.h"
+#include "collectionqueryoptions.h"
 #include "collectionitem.h"
 #include "covermanager/albumcoverloaderoptions.h"
 
@@ -203,9 +205,9 @@ class CollectionModel : public SimpleTreeModel<CollectionItem> {
   void GroupingChanged(CollectionModel::Grouping g, bool separate_albums_by_grouping);
 
  public slots:
-  void SetFilterAge(const int age);
-  void SetFilterText(const QString &text);
-  void SetFilterQueryMode(QueryOptions::QueryMode query_mode);
+  void SetFilterMode(CollectionFilterOptions::FilterMode filter_mode);
+  void SetFilterAge(const int filter_age);
+  void SetFilterText(const QString &filter_text);
 
   void Init(const bool async = true);
   void Reset();
@@ -232,20 +234,21 @@ class CollectionModel : public SimpleTreeModel<CollectionItem> {
   void AlbumCoverLoaded(const quint64 id, const AlbumCoverLoaderResult &result);
 
  private:
-  // Provides some optimisations for loading the list of items in the root.
+  // Provides some optimizations for loading the list of items in the root.
   // This gets called a lot when filtering the playlist, so it's nice to be able to do it in a background thread.
-  QueryResult RunQuery(CollectionItem *parent);
+  CollectionQueryOptions PrepareQuery(CollectionItem *parent);
+  QueryResult RunQuery(const CollectionFilterOptions &filter_options = CollectionFilterOptions(), const CollectionQueryOptions &query_options = CollectionQueryOptions());
   void PostQuery(CollectionItem *parent, const QueryResult &result, const bool signal);
 
-  bool HasCompilations(const QSqlDatabase &db, const CollectionQuery &query);
+  bool HasCompilations(const QSqlDatabase &db, const CollectionFilterOptions &filter_options, const CollectionQueryOptions &query_options);
 
   void BeginReset();
 
   // Functions for working with queries and creating items.
   // When the model is reset or when a node is lazy-loaded the Collection constructs a database query to populate the items.
   // Filters are added for each parent item, restricting the songs returned to a particular album or artist for example.
-  static void InitQuery(const GroupBy group_by, const bool separate_albums_by_grouping, CollectionQuery *q);
-  static void FilterQuery(const GroupBy group_by, const bool separate_albums_by_grouping, CollectionItem *item, CollectionQuery *q);
+  static void SetQueryColumnSpec(const GroupBy group_by, const bool separate_albums_by_grouping, CollectionQueryOptions *query_options);
+  static void AddQueryWhere(const GroupBy group_by, const bool separate_albums_by_grouping, CollectionItem *item, CollectionQueryOptions *query_options);
 
   // Items can be created either from a query that's been run to populate a node, or by a spontaneous SongsDiscovered emission from the backend.
   CollectionItem *ItemFromQuery(const GroupBy group_by, const bool separate_albums_by_grouping, const bool signal, const bool create_divider, CollectionItem *parent, const SqlRow &row, const int container_level);
@@ -279,7 +282,7 @@ class CollectionModel : public SimpleTreeModel<CollectionItem> {
   int total_artist_count_;
   int total_album_count_;
 
-  QueryOptions query_options_;
+  CollectionFilterOptions filter_options_;
   Grouping group_by_;
   bool separate_albums_by_grouping_;
 
