@@ -50,9 +50,9 @@
 #include "core/application.h"
 #include "core/iconloader.h"
 #include "core/mimedata.h"
-#include "core/utilities.h"
 #include "core/musicstorage.h"
 #include "core/deletefiles.h"
+#include "utilities/filemanagerutils.h"
 #include "collection.h"
 #include "collectionbackend.h"
 #include "collectiondirectorymodel.h"
