@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,10 +38,10 @@ class CollectionViewContainer : public QWidget {
   explicit CollectionViewContainer(QWidget *parent = nullptr);
   ~CollectionViewContainer() override;
 
-  CollectionFilterWidget *filter() const;
+  CollectionFilterWidget *filter_widget() const;
   CollectionView *view() const;
 
-  void ReloadSettings();
+  void ReloadSettings() const;
 
  private:
   Ui_CollectionViewContainer *ui_;
