@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +31,7 @@
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
 #include <QMap>
+#include <QHash>
 #include <QVariant>
 #include <QString>
 #include <QStringList>
@@ -105,10 +107,10 @@ class MergedProxyModel : public QAbstractProxyModel {
   void DeleteAllMappings();
   bool IsKnownModel(const QAbstractItemModel *model) const;
 
-  QMap<QAbstractItemModel*, QPersistentModelIndex> merge_points_;
+  QHash<QAbstractItemModel*, QPersistentModelIndex> merge_points_;
   QAbstractItemModel *resetting_model_;
 
-  QMap<QAbstractItemModel*, QModelIndex> old_merge_points_;
+  QHash<QAbstractItemModel*, QModelIndex> old_merge_points_;
 
   std::unique_ptr<MergedProxyModelPrivate> p_;
 };
