@@ -22,6 +22,7 @@
 #include "config.h"
 
 #include <algorithm>
+#include <cmath>
 
 #include <QApplication>
 #include <QCoreApplication>
@@ -45,10 +46,10 @@
 #include "mpris_common.h"
 #include "mpris2.h"
 
-#include "timeconstants.h"
 #include "song.h"
 #include "application.h"
 #include "player.h"
+#include "utilities/timeconstants.h"
 #include "engine/enginebase.h"
 #include "playlist/playlist.h"
 #include "playlist/playlistitem.h"
@@ -175,7 +176,9 @@ void Mpris2::EngineStateChanged(Engine::State newState) {
 
 }
 
-void Mpris2::VolumeChanged() { EmitNotification("Volume"); }
+void Mpris2::VolumeChanged() {
+  EmitNotification("Volume");
+}
 
 void Mpris2::ShuffleModeChanged() { EmitNotification("Shuffle"); }
 
@@ -187,15 +190,15 @@ void Mpris2::RepeatModeChanged() {
 
 }
 
-void Mpris2::EmitNotification(const QString &name, const QVariant &val) {
-  EmitNotification(name, val, "org.mpris.MediaPlayer2.Player");
+void Mpris2::EmitNotification(const QString &name, const QVariant &value) {
+  EmitNotification(name, value, "org.mpris.MediaPlayer2.Player");
 }
 
-void Mpris2::EmitNotification(const QString &name, const QVariant &val, const QString &mprisEntity) {
+void Mpris2::EmitNotification(const QString &name, const QVariant &value, const QString &mprisEntity) {
 
   QDBusMessage msg = QDBusMessage::createSignal(kMprisObjectPath, kFreedesktopPath, "PropertiesChanged");
   QVariantMap map;
-  map.insert(name, val);
+  map.insert(name, value);
   QVariantList args = QVariantList() << mprisEntity << map << QStringList();
   msg.setArguments(args);
   QDBusConnection::sessionBus().send(msg);
@@ -398,6 +401,13 @@ void Mpris2::AlbumCoverLoaded(const Song &song, const AlbumCoverLoaderResult &re
   else if (result.temp_cover_url.isValid() && result.temp_cover_url.isLocalFile()) {
     cover_url = result.temp_cover_url;
   }
+  else if (song.art_manual().isValid() && song.art_manual().isLocalFile() && song.art_manual().path() != Song::kManuallyUnsetCover && song.art_manual().path() != Song::kEmbeddedCover) {
+    cover_url = song.art_manual();
+  }
+  else if (song.art_automatic().isValid() && song.art_automatic().isLocalFile() && song.art_automatic().path() != Song::kManuallyUnsetCover && song.art_automatic().path() != Song::kEmbeddedCover) {
+    cover_url = song.art_automatic();
+  }
+
   if (cover_url.isValid()) AddMetadata("mpris:artUrl", cover_url.toString(), &last_metadata_);
 
   AddMetadata("year", song.year(), &last_metadata_);
@@ -411,8 +421,8 @@ double Mpris2::Volume() const {
   return app_->player()->GetVolume() / 100.0;
 }
 
-void Mpris2::SetVolume(const double value) {
-  app_->player()->SetVolume(static_cast<uint>(std::max(std::min(lround(value * 100.0), 100L), 0L)));
+void Mpris2::SetVolume(const double volume) {
+  app_->player()->SetVolume(static_cast<uint>(qBound(0L, lround(volume * 100.0), 100L)));
 }
 
 qint64 Mpris2::Position() const {
