@@ -27,8 +27,11 @@
 // This translator tries loading strings with an empty context if it can't find any others.
 
 class PoTranslator : public QTranslator {
+  Q_OBJECT
+
  public:
-  QString translate(const char *context, const char *source_text, const char *disambiguation = 0, int n = -1) const {
+  PoTranslator(QObject *parent = nullptr) : QTranslator(parent) {}
+  QString translate(const char *context, const char *source_text, const char *disambiguation = nullptr, int n = -1) const override {
     Q_UNUSED(n);
     QString ret = QTranslator::translate(context, source_text, disambiguation);
     if (!ret.isEmpty()) return ret;
