@@ -21,7 +21,6 @@
 
 #include "config.h"
 
-#include <cstdlib>
 #include <memory>
 #include <algorithm>
 
@@ -37,13 +36,11 @@
 #include <QDirIterator>
 #include <QFile>
 #include <QFileInfo>
-#include <QList>
 #include <QSet>
 #include <QTimer>
 #include <QString>
 #include <QUrl>
 #include <QEventLoop>
-#include <QtDebug>
 
 #include "core/logging.h"
 
@@ -646,7 +643,7 @@ void SongLoader::EndOfStreamReached() {
       if (state_ == Finished) break;
     // It looks like a playlist, so parse it
 
-    // fallthrough
+    [[fallthrough]];
     case WaitingForData:
       // It's a playlist and we've got all the data - finish and parse it
       StopTypefindAsync(true);
