@@ -30,7 +30,6 @@
 #include <QString>
 #include <QImage>
 #include <QSettings>
-#include <QtDebug>
 
 #include "core/logging.h"
 #include "core/workerpool.h"
@@ -39,6 +38,8 @@
 #include "tagreaderclient.h"
 #include "settings/collectionsettingspage.h"
 
+#define DataCommaSizeFromQString(x) (x).toUtf8().constData(), (x).toUtf8().length()
+
 const char *TagReaderClient::kWorkerExecutableName = "strawberry-tagreader";
 TagReaderClient *TagReaderClient::sInstance = nullptr;
 
