@@ -99,7 +99,7 @@ struct CoverProviderSearchResult {
 Q_DECLARE_METATYPE(CoverProviderSearchResult)
 
 // This is a complete result of a single search request (a list of results, each describing one image, actually).
-typedef QList<CoverProviderSearchResult> CoverProviderSearchResults;
+using CoverProviderSearchResults = QList<CoverProviderSearchResult>;
 Q_DECLARE_METATYPE(QList<CoverProviderSearchResult>)
 
 // This class searches for album covers for a given query or artist/album and returns URLs. It's NOT thread-safe.
