@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +35,7 @@ class CoverExportRunnable : public QObject, public QRunnable {
   Q_OBJECT
 
  public:
-  explicit CoverExportRunnable(const AlbumCoverExport::DialogResult &dialog_result, const Song &song);
+  explicit CoverExportRunnable(const AlbumCoverExport::DialogResult &dialog_result, const Song &song, QObject *parent = nullptr);
 
   void run() override;
 
