@@ -44,7 +44,7 @@
 #include "core/application.h"
 #include "core/logging.h"
 #include "core/networkaccessmanager.h"
-#include "core/utilities.h"
+#include "utilities/cryptutils.h"
 #include "albumcoverfetcher.h"
 #include "jsoncoverprovider.h"
 #include "discogscoverprovider.h"
