@@ -44,8 +44,8 @@
 #include "core/application.h"
 #include "core/networkaccessmanager.h"
 #include "core/logging.h"
-#include "core/utilities.h"
-#include "core/timeconstants.h"
+#include "utilities/randutils.h"
+#include "utilities/timeconstants.h"
 #include "internet/localredirectserver.h"
 #include "albumcoverfetcher.h"
 #include "jsoncoverprovider.h"
