@@ -50,8 +50,8 @@
 #include "core/logging.h"
 #include "core/musicstorage.h"
 #include "core/taskmanager.h"
-#include "core/utilities.h"
 #include "core/simpletreemodel.h"
+#include "utilities/strutils.h"
 #include "filesystemdevice.h"
 #include "connecteddevice.h"
 #include "devicelister.h"
