@@ -2,7 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
- * Copyright 2019, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,15 +28,18 @@
 #include <libmtp.h>
 
 #include <QtGlobal>
+#include <QObject>
 #include <QList>
 #include <QUrl>
 
 #include "core/song.h"
 
 class MtpConnection : public QObject, public std::enable_shared_from_this<MtpConnection> {
+  Q_OBJECT
+
  public:
-  MtpConnection(const QUrl &url);
-  ~MtpConnection();
+  explicit MtpConnection(const QUrl &url, QObject *parent = nullptr);
+  ~MtpConnection() override;
 
   bool is_valid() const { return device_; }
   LIBMTP_mtpdevice_t *device() const { return device_; }
