@@ -2,7 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2014, David Sansome <me@davidsansome.com>
- * Copyright 2017, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2017-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ class DeviceFinder {
 
  public:
   struct Device {
+    Device() : card(0), device(0) {}
     QString description;
     QVariant value;
     QString iconname;
@@ -44,7 +45,7 @@ class DeviceFinder {
 
   QString name() const { return name_; }
   QStringList outputs() const { return outputs_; }
-  void add_output(const QString output) { outputs_.append(output); }
+  void add_output(const QString &output) { outputs_.append(output); }
 
   // Does any necessary setup, returning false if this DeviceFinder cannot be used.
   virtual bool Initialize() = 0;
@@ -61,6 +62,7 @@ class DeviceFinder {
   QString name_;
   QStringList outputs_;
 
+  Q_DISABLE_COPY(DeviceFinder)
 };
 
-#endif // DEVICEFINDER_H
+#endif  // DEVICEFINDER_H
