@@ -38,7 +38,7 @@
 #include <QString>
 #include <QUrl>
 
-#include "core/timeconstants.h"
+#include "utilities/timeconstants.h"
 #include "engine_fwd.h"
 #include "enginebase.h"
 #include "gststartup.h"
@@ -61,6 +61,8 @@ class GstEngine : public Engine::Base, public GstBufferConsumer {
   explicit GstEngine(TaskManager *task_manager, QObject *parent = nullptr);
   ~GstEngine() override;
 
+  static const char *kAutoSink;
+
   bool Init() override;
   Engine::State state() const override;
   void StartPreloading(const QUrl &stream_url, const QUrl &original_url, const bool force_stop_at_end, const qint64 beginning_nanosec, const qint64 end_nanosec) override;
@@ -72,7 +74,7 @@ class GstEngine : public Engine::Base, public GstBufferConsumer {
   void Seek(const quint64 offset_nanosec) override;
 
  protected:
-  void SetVolumeSW(const uint percent) override;
+  void SetVolumeSW(const uint volume) override;
 
  public:
   qint64 position_nanosec() const override;
@@ -145,7 +147,6 @@ class GstEngine : public Engine::Base, public GstBufferConsumer {
   static QString GSTdiscovererErrorMessage(GstDiscovererResult result);
 
  private:
-  static const char *kAutoSink;
   static const char *kALSASink;
   static const char *kOpenALSASink;
   static const char *kOSSSink;
