@@ -36,7 +36,7 @@
 #include <QAbstractEventDispatcher>
 
 #include "core/logging.h"
-#include "core/utilities.h"
+#include "utilities/envutils.h"
 
 #ifdef HAVE_MOODBAR
 #  include "ext/gstmoodbar/gstmoodbarplugin.h"
@@ -177,8 +177,4 @@ void GstStartup::SetEnvironment() {
   Utilities::SetEnv("GST_REGISTRY", gst_registry_filename);
 #endif
 
-#ifdef HAVE_LIBPULSE
-  Utilities::SetEnv("PULSE_PROP_media.role", "music");
-#endif
-
 }
