@@ -35,13 +35,16 @@
 #include "ui_globalshortcutgrabber.h"
 
 GlobalShortcutGrabber::GlobalShortcutGrabber(QWidget *parent)
-    : QDialog(parent), ui_(new Ui::GlobalShortcutGrabber) {
+    : QDialog(parent),
+      ui_(new Ui::GlobalShortcutGrabber),
+      wrapper_(nullptr) {
+
   ui_->setupUi(this);
 
   modifier_keys_ << Qt::Key_Shift << Qt::Key_Control << Qt::Key_Meta << Qt::Key_Alt << Qt::Key_AltGr;
 
-  connect(ui_->buttonBox, SIGNAL(accepted()), this, SLOT(Accepted()));
-  connect(ui_->buttonBox, SIGNAL(rejected()), this, SLOT(Rejected()));
+  QObject::connect(ui_->buttonBox, &QDialogButtonBox::accepted, this, &GlobalShortcutGrabber::Accepted);
+  QObject::connect(ui_->buttonBox, &QDialogButtonBox::rejected, this, &GlobalShortcutGrabber::Rejected);
 
 }
 
@@ -90,10 +93,12 @@ bool GlobalShortcutGrabber::event(QEvent *e) {
   if (e->type() == QEvent::ShortcutOverride) {
     QKeyEvent *ke = static_cast<QKeyEvent*>(e);
 
-    if (modifier_keys_.contains(ke->key()))
-      ret_ = QKeySequence(ke->modifiers());
-    else
-      ret_ = QKeySequence(ke->modifiers() | ke->key());
+    if (modifier_keys_.contains(ke->key())) {
+      ret_ = QKeySequence(static_cast<int>(ke->modifiers()));
+    }
+    else {
+      ret_ = QKeySequence(static_cast<int>(ke->modifiers() | ke->key()));
+    }
 
     UpdateText();
 
