@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2018, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 #endif
 
 namespace KeyMapperX11 {
-static const QMap<Qt::Key, quint32> keymapper_x11_ = {
+static const QMap<Qt::Key, quint32> keymapper_x11_ = {  // clazy:exclude=non-pod-global-static
 
 #ifdef HAVE_KEYSYMDEF_H
 
@@ -159,7 +159,7 @@ static const QMap<Qt::Key, quint32> keymapper_x11_ = {
     { Qt::Key_cedilla,            XK_cedilla },
     { Qt::Key_onesuperior,        XK_onesuperior },
     { Qt::Key_masculine,          XK_masculine },
-    { Qt::Key_guillemotright,     XK_guillemotright }, 
+    { Qt::Key_guillemotright,     XK_guillemotright },
     { Qt::Key_onequarter,         XK_onequarter },
     { Qt::Key_onehalf,            XK_onehalf },
     { Qt::Key_threequarters,      XK_threequarters },
@@ -171,7 +171,7 @@ static const QMap<Qt::Key, quint32> keymapper_x11_ = {
     { Qt::Key_Adiaeresis,         XK_Adiaeresis },
     { Qt::Key_Aring,              XK_Aring },
     { Qt::Key_AE,                 XK_AE },
-    { Qt::Key_Ccedilla,           XK_Ccedilla }, 
+    { Qt::Key_Ccedilla,           XK_Ccedilla },
     { Qt::Key_Egrave,             XK_Egrave },
     { Qt::Key_Eacute,             XK_Eacute },
     { Qt::Key_Ecircumflex,        XK_Ecircumflex },
@@ -197,9 +197,9 @@ static const QMap<Qt::Key, quint32> keymapper_x11_ = {
     { Qt::Key_THORN,              XK_THORN },
     { Qt::Key_ssharp,             XK_ssharp },
     { Qt::Key_division,           XK_division },
-    { Qt::Key_ydiaeresis,         XK_ydiaeresis }, 
+    { Qt::Key_ydiaeresis,         XK_ydiaeresis },
     { Qt::Key_Multi_key,          XK_Multi_key },
-    { Qt::Key_Codeinput,          XK_Codeinput }, 
+    { Qt::Key_Codeinput,          XK_Codeinput },
     { Qt::Key_SingleCandidate,    XK_SingleCandidate },
     { Qt::Key_MultipleCandidate,  XK_MultipleCandidate },
     { Qt::Key_PreviousCandidate,  XK_PreviousCandidate },
