@@ -36,12 +36,9 @@
 #include <QPair>
 #include <QList>
 #include <QMap>
-#include <QVariant>
 #include <QString>
 #include <QStringList>
 #include <QRegularExpression>
-#include <QUrl>
-#include <QImage>
 #include <QPixmap>
 #include <QPixmapCache>
 #include <QPainter>
@@ -66,18 +63,16 @@
 #include <QContextMenuEvent>
 #include <QShowEvent>
 #include <QHideEvent>
-#include <QtGlobal>
 
 #include "core/application.h"
 #include "core/mimedata.h"
 #include "core/iconloader.h"
 #include "core/song.h"
-#include "core/logging.h"
 #include "collection/collectionfilterwidget.h"
 #include "collection/collectionmodel.h"
 #include "collection/groupbydialog.h"
+#include "collection/savedgroupingmanager.h"
 #include "covermanager/albumcoverloader.h"
-#include "covermanager/albumcoverloaderoptions.h"
 #include "covermanager/albumcoverloaderresult.h"
 #include "internetsongmimedata.h"
 #include "internetservice.h"
@@ -179,7 +174,7 @@ void InternetSearchView::Init(Application *app, InternetService *service) {
   back_proxy_->sort(0);
 
   // Add actions to the settings menu
-  group_by_actions_ = CollectionFilterWidget::CreateGroupByActions(this);
+  group_by_actions_ = CollectionFilterWidget::CreateGroupByActions(SavedGroupingManager::GetSavedGroupingsSettingsGroup(service_->settings_group()), this);
   QMenu *settings_menu = new QMenu(this);
   settings_menu->addActions(group_by_actions_->actions());
   settings_menu->addSeparator();
