@@ -21,8 +21,6 @@
 #ifndef INTERNETSONGMIMEDATA_H
 #define INTERNETSONGMIMEDATA_H
 
-#include <QMap>
-
 #include "core/mimedata.h"
 #include "core/song.h"
 
@@ -35,7 +33,7 @@ class InternetSongMimeData : public MimeData {
   explicit InternetSongMimeData(InternetService *_service, QObject* = nullptr) : service(_service) {}
 
   InternetService *service;
-  SongMap songs;
+  SongList songs;
 };
 
 #endif  // INTERNETSONGMIMEDATA_H
