@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2018, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <QString>
 #include <QAtomicInt>
 
+class NetworkAccessManager;
 class LyricsProvider;
 
 class LyricsProviders : public QObject {
@@ -48,6 +49,8 @@ class LyricsProviders : public QObject {
   bool HasAnyProviders() const { return !lyrics_providers_.isEmpty(); }
   int NextId();
 
+  NetworkAccessManager *network() const { return network_; }
+
  private slots:
   void ProviderDestroyed();
 
@@ -56,6 +59,8 @@ class LyricsProviders : public QObject {
 
   static int NextOrderId;
 
+  NetworkAccessManager *network_;
+
   QMap<LyricsProvider*, QString> lyrics_providers_;
   QList<LyricsProvider*> ordered_providers_;
   QMutex mutex_;
