@@ -35,7 +35,7 @@
 
 #include "core/logging.h"
 #include "core/networkaccessmanager.h"
-#include "core/utilities.h"
+#include "utilities/strutils.h"
 #include "jsonlyricsprovider.h"
 #include "lyricsfetcher.h"
 #include "musixmatchlyricsprovider.h"
