@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2020-2021, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2020-2022, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,19 +22,23 @@
 
 #include "config.h"
 
+#include <memory>
+
 #include <QtGlobal>
 #include <QObject>
 #include <QList>
 #include <QVariant>
 #include <QString>
+#include <QUrl>
 
 #include "jsonlyricsprovider.h"
 #include "lyricsfetcher.h"
+#include "providers/musixmatchprovider.h"
 
 class QNetworkReply;
 class NetworkAccessManager;
 
-class MusixmatchLyricsProvider : public JsonLyricsProvider {
+class MusixmatchLyricsProvider : public JsonLyricsProvider, public MusixmatchProvider {
   Q_OBJECT
 
  public:
@@ -45,13 +49,32 @@ class MusixmatchLyricsProvider : public JsonLyricsProvider {
   void CancelSearch(const int id) override;
 
  private:
+  struct LyricsSearchContext {
+    explicit LyricsSearchContext() : id(-1) {}
+    int id;
+    QString artist;
+    QString album;
+    QString title;
+    QList<QUrl> requests_lyrics_;
+    LyricsSearchResults results;
+  };
+
+  using LyricsSearchContextPtr = std::shared_ptr<LyricsSearchContext>;
+
+  bool SendSearchRequest(LyricsSearchContextPtr search);
+  bool CreateLyricsRequest(LyricsSearchContextPtr search);
+  bool SendLyricsRequest(LyricsSearchContextPtr search, const QUrl &url);
+  void EndSearch(LyricsSearchContextPtr search, const QUrl &url = QUrl());
   void Error(const QString &error, const QVariant &debug = QVariant()) override;
 
  private slots:
-  void HandleSearchReply(QNetworkReply *reply, const int id, const QString &artist, const QString &album, const QString &title);
+  void HandleSearchReply(QNetworkReply *reply, LyricsSearchContextPtr search);
+  void HandleLyricsReply(QNetworkReply *reply, LyricsSearchContextPtr search, const QUrl &url);
 
  private:
+  QList<LyricsSearchContextPtr> requests_search_;
   QList<QNetworkReply*> replies_;
+  bool rate_limit_exceeded_;
 
 };
 
