@@ -29,7 +29,7 @@
 
 #include "core/logging.h"
 #include "core/networkaccessmanager.h"
-#include "core/utilities.h"
+#include "utilities/strutils.h"
 #include "lyricsfetcher.h"
 #include "jsonlyricsprovider.h"
 #include "ovhlyricsprovider.h"
