@@ -15,8 +15,6 @@
    along with Strawberry.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <string>
-
 #include <QtGlobal>
 #include <QObject>
 #include <QArrayData>
@@ -32,8 +30,6 @@
 
 #include "moodbarrenderer.h"
 
-const int MoodbarRenderer::kNumHues = 12;
-
 ColorVector MoodbarRenderer::Colors(const QByteArray &data, const MoodbarStyle style, const QPalette &palette) {
 
   const int samples = static_cast<int>(data.size() / 3);
