@@ -2,7 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
- * Copyright 2019, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,20 +73,17 @@ class OSDPretty : public QWidget {
 
   bool IsTransparencyAvailable();
 
-  void SetMessage(const QString &summary, const QString& message, const QImage &image);
-  void ShowMessage(const QString &summary, const QString& message, const QImage &image);
-
-  // Controls the fader.  This is enabled by default on Windows.
-  void set_fading_enabled(bool enabled) { fading_enabled_ = enabled; }
+  void SetMessage(const QString &summary, const QString &message, const QImage &image);
+  void ShowMessage(const QString &summary, const QString &message, const QImage &image);
 
   // Popup duration in seconds.  Only used in Mode_Popup.
-  void set_popup_duration(int msec);
+  void set_popup_duration(const int msec);
 
   // These will get overwritten when ReloadSettings() is called
-  void set_foreground_color(QRgb color);
-  void set_background_color(QRgb color);
-  void set_background_opacity(qreal opacity);
-  void set_font(QFont font);
+  void set_foreground_color(const QRgb color);
+  void set_background_color(const QRgb color);
+  void set_background_opacity(const qreal opacity);
+  void set_font(const QFont &font);
 
   QRgb foreground_color() const { return foreground_color_.rgb(); }
   QRgb background_color() const { return background_color_.rgb(); }
@@ -95,18 +92,19 @@ class OSDPretty : public QWidget {
   QPoint popup_pos() const { return popup_pos_; }
   QFont font() const { return font_; }
   bool disable_duration() const { return disable_duration_; }
+  bool fading() const { return fading_enabled_; }
 
   // When the user has been moving the popup, use these to get its current position and screen.
   // Note that these return invalid values if the popup is hidden.
   QScreen *current_screen() const;
-  QScreen *current_screen(const QPoint &pos) const;
+  QScreen *current_screen(const QPoint pos) const;
   QPoint current_pos() const;
 
   // QWidget
   void setVisible(bool visible) override;
 
   bool toggle_mode() const { return toggle_mode_; }
-  void set_toggle_mode(bool toggle_mode) { toggle_mode_ = toggle_mode; }
+  void set_toggle_mode(const bool toggle_mode) { toggle_mode_ = toggle_mode; }
 
  signals:
   void PositionChanged();
@@ -147,7 +145,7 @@ class OSDPretty : public QWidget {
   // Settings loaded from QSettings
   QColor foreground_color_;
   QColor background_color_;
-  float background_opacity_;
+  qreal background_opacity_;
   QString popup_screen_name_;
   QPoint popup_pos_;
   QScreen *popup_screen_;
