@@ -22,7 +22,6 @@
 #include "config.h"
 
 #include <memory>
-#include <functional>
 
 #include <QObject>
 #include <QApplication>
@@ -32,22 +31,18 @@
 #include <QDir>
 #include <QFile>
 #include <QByteArray>
-#include <QHash>
 #include <QList>
-#include <QVariant>
 #include <QString>
-#include <QStringBuilder>
 #include <QStringList>
 #include <QUrl>
 #include <QSqlDatabase>
-#include <QSqlQuery>
-#include <QtDebug>
 
 #include "core/application.h"
 #include "core/database.h"
 #include "core/logging.h"
 #include "core/scopedtransaction.h"
 #include "core/song.h"
+#include "core/sqlquery.h"
 #include "core/sqlrow.h"
 #include "collection/collectionbackend.h"
 #include "playlistitem.h"
@@ -197,7 +192,7 @@ PlaylistItemList PlaylistBackend::GetPlaylistItems(const int playlist) {
       return PlaylistItemList();
     }
 
-    // it's probable that we'll have a few songs associated with the same CUE so we're caching results of parsing CUEs
+    // it's probable that we'll have a few songs associated with the same CUE, so we're caching results of parsing CUEs
     std::shared_ptr<NewSongFromQueryState> state_ptr = std::make_shared<NewSongFromQueryState>();
     while (q.next()) {
       playlistitems << NewPlaylistItemFromQuery(SqlRow(q), state_ptr);
@@ -232,7 +227,7 @@ SongList PlaylistBackend::GetPlaylistSongs(const int playlist) {
       return SongList();
     }
 
-    // it's probable that we'll have a few songs associated with the same CUE so we're caching results of parsing CUEs
+    // it's probable that we'll have a few songs associated with the same CUE, so we're caching results of parsing CUEs
     std::shared_ptr<NewSongFromQueryState> state_ptr = std::make_shared<NewSongFromQueryState>();
     while (q.next()) {
       songs << NewSongFromQuery(SqlRow(q), state_ptr);
