@@ -21,15 +21,14 @@
 
 #include "config.h"
 
-#include <QAbstractItemModel>
 #include <QWidget>
-#include <QFlags>
 #include <QFont>
 #include <QPainter>
 #include <QPalette>
 #include <QRect>
 #include <QPaintEvent>
 
+#include "widgets/autoexpandingtreeview.h"
 #include "playlistlistview.h"
 
 PlaylistListView::PlaylistListView(QWidget *parent) : AutoExpandingTreeView(parent) {}
