@@ -18,11 +18,11 @@
  *
  */
 
-#include "playlistparsers/parserbase.h"
-#include "xmlparser.h"
-
 #include <QObject>
 
+#include "parserbase.h"
+#include "xmlparser.h"
+
 class CollectionBackendInterface;
 
 XMLParser::XMLParser(CollectionBackendInterface *collection, QObject *parent)
