@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2018, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 
 #include <QtGlobal>
 #include <QObject>
+#include <QMap>
 #include <QString>
 #include <QUrl>
 
@@ -40,15 +41,22 @@ class QobuzUrlHandler : public UrlHandler {
   QString scheme() const { return service_->url_scheme(); }
   LoadResult StartLoading(const QUrl &url);
 
-  void CancelTask();
+ private:
+  void CancelTask(const int task_id);
 
  private slots:
-  void GetStreamURLFinished(const QUrl &original_url, const QUrl &stream_url, const Song::FileType filetype, const int samplerate, const int bit_depth, const qint64 duration, QString error = QString());
+  void GetStreamURLFailure(const uint id, const QUrl &original_url, const QString &error);
+  void GetStreamURLSuccess(const uint id, const QUrl &original_url, const QUrl &stream_url, const Song::FileType filetype, const int samplerate, const int bit_depth, const qint64 duration);
 
  private:
+  struct Request {
+    Request() : id(0), task_id(-1) {}
+    uint id;
+    int task_id;
+  };
   Application *app_;
   QobuzService *service_;
-  int task_id_;
+  QMap<uint, Request> requests_;
 
 };
 
