@@ -22,9 +22,7 @@
 #include <QThread>
 #include <QMutexLocker>
 #include <QSqlDatabase>
-#include <QSqlQuery>
 
-#include "core/logging.h"
 #include "core/database.h"
 #include "core/sqlquery.h"
 #include "core/song.h"
