@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2018, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,20 +19,18 @@
 
 #include "config.h"
 
-#include <QObject>
 #include <QtGlobal>
 #include <QString>
 
 #include "scrobblercacheitem.h"
 
-ScrobblerCacheItem::ScrobblerCacheItem(const QString &artist, const QString &album, const QString &song, const QString &albumartist, const int track, const qint64 duration, const quint64 &timestamp) :
-  artist_(artist),
-  album_(album),
-  song_(song),
-  albumartist_(albumartist),
-  track_(track),
-  duration_(duration),
-  timestamp_(timestamp),
-  sent_(false) {}
-
-ScrobblerCacheItem::~ScrobblerCacheItem() {}
+ScrobblerCacheItem::ScrobblerCacheItem(const QString &artist, const QString &album, const QString &song, const QString &albumartist, const int track, const qint64 duration, const quint64 timestamp, QObject *parent)
+    : QObject(parent),
+      artist_(artist),
+      album_(album),
+      song_(song),
+      albumartist_(albumartist),
+      track_(track),
+      duration_(duration),
+      timestamp_(timestamp),
+      sent_(false) {}
