@@ -54,7 +54,7 @@ class SubsonicScrobbler : public ScrobblerService {
   void Scrobble(const Song &song) override;
   void Error(const QString &error, const QVariant &debug = QVariant()) override;
 
-  void DoSubmit() override {}
+  void StartSubmit(const bool initial = false) override { Q_UNUSED(initial) }
   void Submitted() override { submitted_ = true; }
   bool IsSubmitted() const override { return submitted_; }
 
