@@ -73,7 +73,7 @@ CollectionSettingsPage::CollectionSettingsPage(SettingsDialog *dialog, QWidget *
   ui_->list->setItemDelegate(new NativeSeparatorsDelegate(this));
 
   // Icons
-  setWindowIcon(IconLoader::Load("library-music"));
+  setWindowIcon(IconLoader::Load("library-music", true, 0, 32));
   ui_->add->setIcon(IconLoader::Load("document-open-folder"));
 
   ui_->combobox_cache_size->addItems({ "KB", "MB" });
