@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2012, David Sansome <me@davidsansome.com>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,7 @@ class MoodbarSettingsPage : public SettingsPage {
   Q_OBJECT
 
  public:
-  explicit MoodbarSettingsPage(SettingsDialog* dialog);
+  explicit MoodbarSettingsPage(SettingsDialog *dialog, QWidget *parent = nullptr);
   ~MoodbarSettingsPage() override;
 
   static const char *kSettingsGroup;
@@ -48,7 +49,7 @@ class MoodbarSettingsPage : public SettingsPage {
 
   void InitMoodbarPreviews();
 
-  Ui_MoodbarSettingsPage* ui_;
+  Ui_MoodbarSettingsPage *ui_;
 
   bool initialized_;
 };
