@@ -38,8 +38,16 @@ class PlaylistSettingsPage : public SettingsPage {
  public:
   explicit PlaylistSettingsPage(SettingsDialog *dialog, QWidget *parent = nullptr);
   ~PlaylistSettingsPage() override;
+
   static const char *kSettingsGroup;
 
+  enum PathType {
+    PathType_Automatic = 0,  // Automatically select path type
+    PathType_Absolute,       // Always use absolute paths
+    PathType_Relative,       // Always use relative paths
+    PathType_Ask_User,       // Only used in preferences: to ask user which of the previous values he wants to use.
+  };
+
   void Load() override;
   void Save() override;
 
