@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ class TranscoderSettingsPage : public SettingsPage {
   Q_OBJECT
 
  public:
-  explicit TranscoderSettingsPage(SettingsDialog *dialog);
+  explicit TranscoderSettingsPage(SettingsDialog *dialog, QWidget *parent = nullptr);
   ~TranscoderSettingsPage() override;
 
   static const char *kSettingsGroup;
