@@ -41,9 +41,9 @@
 #include "core/application.h"
 #include "core/logging.h"
 #include "core/song.h"
-#include "core/timeconstants.h"
-#include "core/imageutils.h"
 #include "core/networktimeouts.h"
+#include "utilities/imageutils.h"
+#include "utilities/timeconstants.h"
 #include "subsonicservice.h"
 #include "subsonicurlhandler.h"
 #include "subsonicbaserequest.h"
