@@ -21,9 +21,7 @@
 #include "config.h"
 
 #include <QWidget>
-#include <QVariant>
 #include <QString>
-#include <QStringBuilder>
 #include <QSlider>
 #include <QSettings>
 
