@@ -27,9 +27,11 @@
 #include <QString>
 
 class TranscoderOptionsInterface : public QWidget {
-public:
-  TranscoderOptionsInterface(QWidget *parent) : QWidget(parent) {}
-  virtual ~TranscoderOptionsInterface() {}
+  Q_OBJECT
+
+ public:
+  explicit TranscoderOptionsInterface(QWidget *parent) : QWidget(parent) {}
+  ~TranscoderOptionsInterface() override {}
 
   virtual void Load() = 0;
   virtual void Save() = 0;
