@@ -29,14 +29,16 @@
 class Ui_TranscoderOptionsWavPack;
 
 class TranscoderOptionsWavPack : public TranscoderOptionsInterface {
+  Q_OBJECT
+
  public:
-  TranscoderOptionsWavPack(QWidget *parent = nullptr);
-  ~TranscoderOptionsWavPack();
+  explicit TranscoderOptionsWavPack(QWidget *parent = nullptr);
+  ~TranscoderOptionsWavPack() override;
 
-  void Load();
-  void Save();
+  void Load() override;
+  void Save() override;
 
-private:
+ private:
   static const char *kSettingsGroup;
 
   Ui_TranscoderOptionsWavPack *ui_;
