@@ -23,6 +23,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QFileSystemModel>
+#include <QFileIconProvider>
 #include <QString>
 #include <QStringList>
 #include <QUrl>
@@ -59,7 +60,7 @@ FileView::FileView(QWidget *parent)
       model_(nullptr),
       undo_stack_(new QUndoStack(this)),
       task_manager_(nullptr),
-      storage_(new FilesystemMusicStorage("/")) {
+      storage_(new FilesystemMusicStorage(Song::Source_LocalFile, "/")) {
 
   ui_->setupUi(this);
 
@@ -266,6 +267,10 @@ void FileView::showEvent(QShowEvent *e) {
   if (model_) return;
 
   model_ = new QFileSystemModel(this);
+  if (!model_->iconProvider() || model_->iconProvider()->icon(QFileIconProvider::Folder).isNull()) {
+    file_icon_provider_ = std::make_unique<QFileIconProvider>();
+    model_->setIconProvider(file_icon_provider_.get());
+  }
 
   model_->setNameFilters(filter_list_);
   // if an item fails the filter, hide it
