@@ -18,9 +18,6 @@
  *
  */
 
-#include "config.h"
-
-#include <QtGlobal>
 #include <QWidget>
 #include <QListView>
 #include <QAbstractItemModel>
@@ -28,8 +25,6 @@
 #include <QAbstractItemDelegate>
 #include <QItemSelectionModel>
 #include <QList>
-#include <QArrayData>
-#include <QVariant>
 #include <QString>
 #include <QFont>
 #include <QFontMetrics>
@@ -174,7 +169,7 @@ void GroupedIconView::LayoutItems() {
 
       headers_ << header;
 
-      // Remember this group so we don't add it again.
+      // Remember this group, so we don't add it again.
       last_group = group;
 
       // Move the next item immediately below the header.
